@@ -6,14 +6,27 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna.php 572 2008-06-08 01:31:35Z mumumu-org $
+ *  @version    $Id: Ethna.php 646 2008-09-30 17:11:06Z mumumu-org $
  */
 
-/** Ethna depends on PEAR */
-require_once 'PEAR.php';
+//
+//  PEAR OS_WINDOWS constant replacement.
+//
+//  PEAR の OS_WINDOWS 定数は、defined関数で
+//  既に定義されているかをチェックしていない。
+//  よって require_once 'PEAR.php' とすると
+//  E_NOTICEが出ることから、Windows環境判定用
+//  として独自の定数を定義する
+//
+if (substr(PHP_OS, 0, 3) == 'WIN'
+ && !defined('ETHNA_OS_WINDOWS')) {
+    define('ETHNA_OS_WINDOWS', true);
+} elseif (!defined('ETHNA_OS_WINDOWS')) {
+    define('ETHNA_OS_WINDOWS', false);
+}
 
 if (!defined('PATH_SEPARATOR')) {
-    if (OS_WINDOWS) {
+    if (ETHNA_OS_WINDOWS) {
         /** include_path separator(Windows) */
         define('PATH_SEPARATOR', ';');
     } else {
@@ -22,7 +35,7 @@ if (!defined('PATH_SEPARATOR')) {
     }
 }
 if (!defined('DIRECTORY_SEPARATOR')) {
-    if (OS_WINDOWS) {
+    if (ETHNA_OS_WINDOWS) {
         /** directory separator(Windows) */
         define('DIRECTORY_SEPARATOR', '\\');
     } else {
@@ -32,7 +45,13 @@ if (!defined('DIRECTORY_SEPARATOR')) {
 }
 
 /** バージョン定義 */
-define('ETHNA_VERSION', '2.5.0-preview1');
+define('ETHNA_VERSION', '2.5.0-preview2');
+
+/**
+ * ダミーのエラーモード
+ * PEAR非依存、かつ互換性を維持するためのもの
+ */
+define('ETHNA_ERROR_DUMMY', 'dummy');
 
 /** Ethnaベースディレクトリ定義 */
 define('ETHNA_BASE', dirname(__FILE__));
@@ -299,13 +318,37 @@ $GLOBALS['_Ethna_error_message_list'] = array();
  *  @access     public
  *  @package    Ethna
  */
-class Ethna extends PEAR
+class Ethna
 {
-    /**#@+
-     *  @access private
+    /**
+     *  渡されたオブジェクトが Ethna_Error オブジェクト
+     *  またはそのサブクラスのオブジェクトかどうかチェックします。
+     *
+     *  @param mixed  $data    チェックする変数
+     *  @param mixed  $msgcode チェックするエラーメッセージまたはエラーコード  
+     *  @return mixed 変数が、Ethna_Error の場合に TRUEを返します。
+     *                第2引数が設定された場合は、さらに 所与された $msgcode
+     *                を含む場合のみ TRUEを返します。
+     *  @static
      */
+    function isError($data, $msgcode = NULL)
+    {
+        if (!is_object($data)) {
+            return false;
+        }
 
-    /**#@-*/
+        $class_name = get_class($data);
+        if (strcasecmp($class_name, 'Ethna_Error') === 0
+         || is_subclass_of($data, 'Ethna_Error')) {
+            if ($msgcode == NULL) {
+                return true;
+            } elseif ($data->getCode() == $msgcode) {
+                return true;
+            }
+        }
+
+        return false;
+    }
 
     /**
      *  Ethna_Errorオブジェクトを生成する(エラーレベル:E_USER_ERROR)
@@ -324,7 +367,8 @@ class Ethna extends PEAR
                 $userinfo = $userinfo[0];
             }
         }
-        return PEAR::raiseError($message, $code, PEAR_ERROR_RETURN, E_USER_ERROR, $userinfo, 'Ethna_Error');
+        $error = new Ethna_Error($message, $code, ETHNA_ERROR_DUMMY, E_USER_ERROR, $userinfo, 'Ethna_Error');
+        return $error;
     }
 
     /**
@@ -344,7 +388,9 @@ class Ethna extends PEAR
                 $userinfo = $userinfo[0];
             }
         }
-        return PEAR::raiseError($message, $code, PEAR_ERROR_RETURN, E_USER_WARNING, $userinfo, 'Ethna_Error');
+
+        $error = new Ethna_Error($message, $code, ETHNA_ERROR_DUMMY, E_USER_WARNING, $userinfo, 'Ethna_Error');
+        return $error;
     }
 
     /**
@@ -364,7 +410,9 @@ class Ethna extends PEAR
                 $userinfo = $userinfo[0];
             }
         }
-        return PEAR::raiseError($message, $code, PEAR_ERROR_RETURN, E_USER_NOTICE, $userinfo, 'Ethna_Error');
+
+        $error = new Ethna_Error($message, $code, ETHNA_ERROR_DUMMY, E_USER_NOTICE, $userinfo, 'Ethna_Error');
+        return $error;
     }
 
     /**
@@ -409,11 +457,13 @@ class Ethna extends PEAR
 
                 // perform some more checks?
                 $object->$method($error);
-            } else {
+            } else {  
+                //  call statically
                 call_user_func($callback, $error);
             }
         }
     }
 }
 // }}}
+
 ?>
