@@ -7,41 +7,33 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: ethna_handle.php 529 2008-05-07 23:57:32Z mumumu-org $
+ *  @version    $Id: ethna_handle.php 647 2008-10-04 16:04:39Z mumumu-org $
  */
 while (ob_get_level()) {
     ob_end_clean();
 }
 
-// setup path seprator
-if (!defined('PATH_SEPARATOR')) {
-    if (OS_WINDOWS) {
-        /** include_path separator(Windows) */
-        define('PATH_SEPARATOR', ';');
-    } else {
-        /** include_path separator(Unix) */
-        define('PATH_SEPARATOR', ':');
-    }
-}
 $base = dirname(dirname(dirname(__FILE__)));
 ini_set('include_path', $base.PATH_SEPARATOR.ini_get('include_path'));
 
-require_once 'PEAR.php';
-require_once 'Console/Getopt.php';
 require_once 'Ethna/Ethna.php';
+require_once ETHNA_BASE . '/class/Ethna_Getopt.php';
 
 // fetch arguments
-$arg_list = Console_Getopt::readPHPArgv();
+$opt = new Ethna_Getopt();
+$arg_list = $opt->readPHPArgv();
 if (Ethna::isError($arg_list)) {
     echo $arg_list->getMessage()."\n";
     exit(2);
 }
-array_shift($arg_list);
+array_shift($arg_list);  // remove "ethna_handle.php"
 
 $eh =& new Ethna_Handle();
 
+//  はじめの引数に - が含まれていればそれを分離する
+//  含まれていた場合、それは -v|--version でなければならない
 list($my_arg_list, $arg_list) = _Ethna_HandleGateway_SeparateArgList($arg_list);
-$r = Console_Getopt::getopt($my_arg_list, "v", array("version"));
+$r = $opt->getopt($my_arg_list, "v", array("version"));
 if (Ethna::isError($r)) {
     usage($eh);
     exit(1);
@@ -101,6 +93,10 @@ function usage(&$eh)
 function _Ethna_HandleGateway_SeparateArgList($arg_list)
 {
     $my_arg_list = array();
+
+    //  はじめの引数に - が含まれていたら、
+    //  それを $my_arg_list に入れる
+    //  これは --version 判定のため 
     for ($i = 0; $i < count($arg_list); $i++) {
         if ($arg_list[$i]{0} == '-') {
             // assume this should be an option for myself
@@ -120,7 +116,7 @@ function _Ethna_HandleGateway_SeparateArgList($arg_list)
 function _Ethna_HandleGateway_ShowVersion()
 {
     $version = <<<EOD
-Ethna %s
+Ethna %s (using PHP %s)
 
 Copyright (c) 2004-%s,
   Masaki Fujimoto <fujimoto@php.net>
@@ -128,10 +124,11 @@ Copyright (c) 2004-%s,
   Takuya Ookubo <sfio@sakura.ai.to>
   nozzzzz <nozzzzz@gmail.com>
   cocoitiban <cocoiti@comio.info>
+  Yoshinari Takaoka <takaoka@beatcraft.com>
 
 http://ethna.jp/
 
 EOD;
-    printf($version, ETHNA_VERSION, date('Y'));
+    printf($version, ETHNA_VERSION, PHP_VERSION, date('Y'));
 }
 ?>
