@@ -6,7 +6,7 @@
  *
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: ethna_make_package.php 595 2008-06-30 13:57:21Z mumumu-org $
  */
 require_once 'PEAR.php';
 require_once 'Console/Getopt.php';
@@ -113,13 +113,8 @@ $packagexml->addIgnoreToRelease('bin/ethna.bat');
 $packagexml->generateContents();
 
 if ($is_old_package) {
-    if (method_exists($packagexml, 'exportCompatiblePackageFile1')) {
-        $pkg =& $packagexml->exportCompatiblePackageFile1();
-        $pkg->writePackageFile();
-    } else {
-        //  PEAR package version 1 is not supported over PEAR 1.8.0.
-        echo "WARNING: PEAR package version 1 is not supported in this PEAR version.\n";
-    }
+    $pkg =& $packagexml->exportCompatiblePackageFile1();
+    $pkg->writePackageFile();
 } else {
     $packagexml->writePackageFile();
 }
