@@ -7,14 +7,14 @@
  *  @author     Kazuhiro Hosoi <hosoi@gree.co.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: ethna_run_test.php 488 2007-12-13 22:11:18Z mumumu-org $
+ *  @version    $Id: ethna_run_test.php 648 2008-10-04 23:21:17Z mumumu-org $
  */
 
-/** アプリケーションベースディレクトリ */
-define('BASE', dirname(dirname(__FILE__)));
+/** Ethnaインストールルートディレクトリ */
+define('ETHNA_INSTALL_BASE', dirname(dirname(__FILE__)));
 
 /** include_pathの設定(このtest runnerがあるディレクトリを追加) */
-ini_set('include_path', dirname(BASE) . PATH_SEPARATOR . ini_get('include_path'));
+ini_set('include_path', dirname(ETHNA_INSTALL_BASE) . PATH_SEPARATOR . ini_get('include_path'));
 
 /** Ethna関連クラスのインクルード */
 require_once 'Ethna/Ethna.php';
@@ -31,9 +31,10 @@ $test_dir = ETHNA_BASE . '/test';
 $test = &new GroupTest('Ethna All tests');
 
 // テストケースのファイルリストを取得
-require_once 'Console/Getopt.php';
-$args = Console_Getopt::readPHPArgv();
-list($args, $opts) = Console_Getopt::getopt2($args, '', array());
+require_once ETHNA_BASE . '/class/Ethna_Getopt.php';
+$opt = new Ethna_Getopt();
+$args = $opt->readPHPArgv();
+list($args, $opts) = $opt->getopt($args, '', array());
 array_shift($opts);
 if (count($opts) > 0) {
     $file_list = $opts;
@@ -47,7 +48,6 @@ foreach ($file_list as $file) {
 }
 
 // 結果をコマンドラインに出力
-//$test->run(new TextReporter());
 $test->run(new TextDetailReporter());
 
 //{{{ getFileList
@@ -89,4 +89,5 @@ function getFileList($dir_path)
     return $file_list;
 }
 //}}}
+
 ?>
