@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Controller.php 597 2008-06-30 14:43:54Z mumumu-org $
+ *  @version    $Id: Ethna_Controller.php 660 2008-10-10 08:39:20Z mumumu-org $
  */
 
 // {{{ Ethna_Controller
@@ -313,6 +313,7 @@ class Ethna_Controller
 
         //    アプリケーションIDはクラス名のprefixともなるため、
         //    数字で始まっていてはいけない
+        //    @see http://www.php.net/manual/en/language.variables.php
         if (preg_match('/^[a-zA-Z][a-zA-Z0-9]*$/', $id) === 0) {
             $msg = (preg_match('/^[0-9]$/', $id[0]))
                  ? "Application ID must NOT start with Number.\n"
@@ -510,11 +511,6 @@ class Ethna_Controller
      */
     function getDirectory($key)
     {
-        // for B.C.
-        if ($key == 'app' && isset($this->directory[$key]) == false) {
-            return BASE . '/app';
-        }
-
         if (isset($this->directory[$key]) == false) {
             return null;
         }
@@ -944,21 +940,21 @@ class Ethna_Controller
         }
         $this->action_name = $action_name;
 
-        // ロケール/言語設定
-        $this->_setLanguage($this->locale, $this->system_encoding, $this->client_encoding);
-
         // オブジェクト生成
         $backend =& $this->getBackend();
 
         $form_name = $this->getActionFormName($action_name);
         $this->action_form =& new $form_name($this);
         $this->action_form->setFormVars();
-
-        // バックエンド処理実行
         $backend->setActionForm($this->action_form);
 
+        // アクションに必要とされる全てのオブジェクトが
+        // 初期化されたあと、言語切り替えフックを呼ぶ
         $session =& $this->getSession();
         $session->restore();
+        $this->_setLanguage($this->locale, $this->system_encoding, $this->client_encoding);
+
+        // バックエンド処理実行
         $forward_name = $backend->perform($action_name);
 
         // アクション実行後フィルタ
@@ -1833,6 +1829,9 @@ class Ethna_Controller
         $this->system_encoding = $system_encoding;
         $this->client_encoding = $client_encoding;
 
+        //   $this->locale, $this->client_encoding を書き換えた場合は
+        //   必ず Ethna_I18N クラスの setLanguageメソッドも呼ぶこと!
+        //   さもないとカタログその他が再ロードされない！
         $i18n =& $this->getI18N();
         $i18n->setLanguage($locale, $system_encoding, $client_encoding);
     }
