@@ -6,7 +6,7 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_PearWrapper.php 488 2007-12-13 22:11:18Z mumumu-org $
+ *  @version    $Id: Ethna_PearWrapper.php 627 2008-08-04 22:14:08Z mumumu-org $
  */
 
 require_once 'PEAR.php';
@@ -648,8 +648,9 @@ class Ethna_PearWrapper
     {
         $short_args = $long_args = null;
         PEAR_Command::getGetOptArgs($cmd_str, $short_args, $long_args);
-        $opt_arg = Console_GetOpt::getOpt2($opt_array, $short_args, $long_args);
-        if (PEAR::isError($opt_arg)) return array();
+        $opt = new Ethna_Getopt();
+        $opt_arg = $opt->getopt($opt_array, $short_args, $long_args);
+        if (Ethna::isError($opt_arg)) return array();
         $opts = array();
         foreach ($opt_arg[0] as $tmp) {
             list($opt, $val) = $tmp;
