@@ -5,7 +5,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_SmartyPlugin.php 580 2008-06-13 15:52:53Z mumumu-org $
+ *  @version    $Id: Ethna_SmartyPlugin.php 643 2008-09-19 17:40:31Z mumumu-org $
  */
 
 // {{{ smarty_modifier_number_format
@@ -331,15 +331,15 @@ function smarty_modifier_i18n($string)
  *  </code>
  *  <code>
  *  <input type="checkbox" name="test">
- *  <input type="checkbox" name="test" checkbox>
+ *  <input type="checkbox" name="test" checked>
  *  </code>
  *
- *  @param  string  $string チェックボックスに渡されたフォーム値
- *  @return string  $stringが空文字列あるいは0以外の場合は"checked"
+ *  @param  string  $string チェックボックスに渡されたフォーム値(スカラーのみ)
+ *  @return string  $stringが空文字列あるいは0, null, false 以外の場合は"checked"
  */
 function smarty_modifier_checkbox($string)
 {
-    if ($string != "" && $string != 0) {
+    if (is_scalar($string) && $string != "" && $string != "0") {
         return "checked";
     }
 }
@@ -360,7 +360,7 @@ function smarty_modifier_checkbox($string)
  *  <option value="2" {$form|select:"2"}>bar</option>
  *  </code>
  *  <code>
- *  <option value="1" selected>foo</option>
+ *  <option value="1" selected="selected">foo</option>
  *  <option value="2" >bar</option>
  *  </code>
  *
@@ -497,6 +497,24 @@ function smarty_function_uniqid($params, &$smarty)
 /**
  *  smarty function:セレクトフィールド生成
  *
+ *  sample:
+ *  <code>
+ *  $smarty->assign('hoge',
+ *                   array(
+ *                       '1' => array('name' => 'foo'),
+ *                       '2' => array('name' => 'bar')
+ *                   )
+ *  );
+ *  {select list=$hoge name="hoge" value="1" empty="-- please select --"}
+ *  </code>
+ *  <code>
+ *  <select name="hoge">
+ *    <option value="">-- please select --</option>
+ *    <option value="1" selected="selected">foo</option>
+ *    <option value="2">bar</option>
+ *  </select>
+ *  </code>
+ *
  *  @param  array   $list   選択肢一覧
  *  @param  string  $name   フォーム項目名
  *  @param  string  $value  セレクトボックスに渡されたフォーム値
@@ -507,12 +525,21 @@ function smarty_function_select($params, &$smarty)
 {
     extract($params);
 
+    //  empty="...." を加えると、無条件に追加される
+    //  ない場合は追加されない
     print "<select name=\"$name\">\n";
     if ($empty) {
         printf("<option value=\"\">%s</option>\n", $empty);
     }
     foreach ($list as $id => $elt) {
-        printf("<option value=\"%s\" %s>%s</option>\n", $id, $id == $value ? 'selected="true"' : '', $elt['name']);
+        //    標準に合わせる
+        //    @see http://www.w3.org/TR/html401/interact/forms.html#adef-selected
+        //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-transitional.dtd
+        //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-strict.dtd
+        //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-frameset.dtd
+        //    @see http://www.w3.org/TR/xhtml-modularization/abstract_modules.html#s_sformsmodule
+        printf("<option value=\"%s\" %s>%s</option>\n",
+               $id, $id == $value ? 'selected="selected"' : '', $elt['name']);
     }
     print "</select>\n";
 }
