@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_ViewClass.php 601 2008-07-01 12:48:18Z mumumu-org $
+ *  @version    $Id: Ethna_ViewClass.php 661 2008-10-10 08:53:09Z mumumu-org $
  */
 
 // {{{ Ethna_ViewClass
@@ -23,6 +23,9 @@ class Ethna_ViewClass
      *  @access private
      */
 
+    /** @var    object  Ethna_Controller    Controllerオブジェクト */
+    var $ctl;
+
     /** @var    object  Ethna_Backend       backendオブジェクト */
     var $backend;
 
@@ -79,6 +82,7 @@ class Ethna_ViewClass
     function Ethna_ViewClass(&$backend, $forward_name, $forward_path)
     {
         $c =& $backend->getController();
+        $this->ctl =& $c;
         $this->backend =& $backend;
         $this->config =& $this->backend->getConfig();
         $this->i18n =& $this->backend->getI18N();
@@ -127,7 +131,6 @@ class Ethna_ViewClass
      */
     function forward()
     {
-        $this->_setLanguage();
         $renderer =& $this->_getRenderer();
         $this->_setDefault($renderer);
         $renderer->perform($this->forward_path);
@@ -905,21 +908,6 @@ class Ethna_ViewClass
      *  @return object  Ethna_Renderer  レンダラオブジェクト
      */
     function &_getRenderer()
-    {
-        $_ret_object =& $this->_getTemplateEngine();
-        return $_ret_object;
-    }
-    // }}}
-
-    // {{{ _getTemplateEngine
-    /**
-     *  レンダラオブジェクトを取得する(そのうち_getRenderer()に統合される予定)
-     *
-     *  @access protected
-     *  @return object  Ethna_Renderer  レンダラオブジェクト
-     *  @obsolete
-     */
-    function &_getTemplateEngine()
     {
         $c =& $this->backend->getController();
         $renderer =& $c->getRenderer();
@@ -959,19 +947,6 @@ class Ethna_ViewClass
     {
     }
     // }}}
-
-    // {{{ _setLanguage
-    /**
-     *  言語設定を設定する。
-     *  アクションフォームやCookieの値等で、テンプレートや言語設定
-     *  を切り替えたい場合にオーバーライドしてください。
-     *
-     *  @access protected
-     */
-    function _setLanguage()
-    {
-    }
-    // }}}
 }
 // }}}
 ?>
