@@ -10,7 +10,7 @@
  *
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Cachemanager_Memcache.php 488 2007-12-13 22:11:18Z mumumu-org $
+ *  @version    $Id: Ethna_Plugin_Cachemanager_Memcache.php 627 2008-08-04 22:14:08Z mumumu-org $
  */
 
 /**
@@ -69,10 +69,10 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
         $this->memcache_pool["$host:$port"] =& new MemCache();
 
         while ($retry > 0) {
-            if ($this->config->get('memcache_use_connect')) {
-                $r = $this->memcache_pool["$host:$port"]->connect($host, $port, $timeout);
-            } else {
+            if ($this->config->get('memcache_use_pconnect')) {
                 $r = $this->memcache_pool["$host:$port"]->pconnect($host, $port, $timeout);
+            } else {
+                $r = $this->memcache_pool["$host:$port"]->connect($host, $port, $timeout);
             }
             if ($r) {
                 break;
@@ -134,7 +134,7 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
      *
      *  キャッシュに値が設定されている場合はキャッシュ値
      *  が戻り値となる。キャッシュに値が無い場合やlifetime
-     *  を過ぎている場合、エラーが発生した場合はPEAR_Error
+     *  を過ぎている場合、エラーが発生した場合はEthna_Error
      *  オブジェクトが戻り値となる。
      *
      *  @access public
@@ -213,7 +213,7 @@ class Ethna_Plugin_Cachemanager_Memcache extends Ethna_Plugin_Cachemanager
     {
         $r = $this->get($key, $lifetime, $namespace);
 
-        return PEAR::isError($r) ? false: true;
+        return Ethna::isError($r) ? false: true;
     }
 
     /**
