@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id$
+ *  @version    $Id: Ethna_Plugin_Generator_AppManager.php 488 2007-12-13 22:11:18Z mumumu-org $
  */
 
 // {{{ Ethna_Plugin_Generator_AppManager
@@ -28,14 +28,15 @@ class Ethna_Plugin_Generator_AppManager extends Ethna_Plugin_Generator
      */
     function generate($manager_name)
     {
-        $class_name = $this->ctl->getManagerClassName($manager_name);
+        $manager_id = preg_replace('/_(.)/e', "strtoupper('\$1')", ucfirst($manager_name));
+
         $app_dir = $this->ctl->getDirectory('app');
-        $app_path = "${class_name}.php";
+        $app_path = ucfirst($this->ctl->getAppId()) . '_' . $manager_id .'Manager.php';
 
         $macro = array();
         $macro['project_id'] = $this->ctl->getAppId();
         $macro['app_path'] = $app_path;
-        $macro['app_manager'] = $class_name;
+        $macro['app_manager'] = ucfirst($this->ctl->getAppId()) . '_' . $manager_id;
 
         $user_macro = $this->_getUserMacro();
         $macro = array_merge($macro, $user_macro);
