@@ -15,7 +15,7 @@ require_once 'rhaco/tag/TemplateParser.php';
 require_once ETHNA_BASE . '/class/Ethna_SmartyPlugin.php';
 
 /**
- *  Rhaco饯饹
+ *  Rhacoレンダラクラス
  *
  *  @access     public
  *  @package    Ethna
@@ -42,7 +42,7 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     var $engine;
     
     /**
-     *  Ethna_Renderer_Rhaco饹Υ󥹥ȥ饯
+     *  Ethna_Renderer_Rhacoクラスのコンストラクタ
      *
      *  @access public
      */
@@ -65,7 +65,7 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
         $this->engine->compile_dir = $this->compile_dir;
         $this->engine->compile_id = md5($this->template_dir);
 
-        // ФäƤߤ
+        // 一応がんばってみる
         if (is_dir($this->engine->compile_dir) === false) {
             Ethna_Util::mkdir($this->engine->compile_dir, 0755);
         }
@@ -74,11 +74,11 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
     
     /**
-     *  ӥ塼Ϥ
+     *  ビューを出力する
      *
      *  @access public
-     *  @param  string  $template   ƥץ졼̾
-     *  @param  bool    $capture    true ʤнϤɽ֤
+     *  @param  string  $template   テンプレート名
+     *  @param  bool    $capture    true ならば出力を表示せずに返す
      */
     function perform($template = null, $capture = false)
     {
@@ -105,12 +105,12 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
     
     /**
-     * ƥץ졼ѿ
+     * テンプレート変数を取得する
      * 
      *  @todo fixme
      *  @access public
-     *  @param string $name  ѿ̾
-     *  @return mixedѿ
+     *  @param string $name  変数名
+     *  @return mixed　変数
      */
     function &getProp($name = null)
     {
@@ -124,9 +124,9 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿ
+     *  テンプレート変数を削除する
      * 
-     *  @param name    ѿ̾
+     *  @param name    変数名
      *  @todo
      *  @access public
      */
@@ -136,7 +136,7 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿƤ
+     *  テンプレート変数に配列を割り当てる
      * 
      *  @param array $array
      *  @access public
@@ -147,7 +147,7 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿ򻲾ȤȤƳƤ
+     *  テンプレート変数に配列を参照として割り当てる
      * 
      *  @param array $array
      *  @todo no implement
@@ -159,10 +159,10 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿƤ
+     *  テンプレート変数を割り当てる
      * 
-     *  @param string $name ѿ̾
-     *  @param mixed $value 
+     *  @param string $name 変数名
+     *  @param mixed $value 値
      * 
      *  @access public
      */
@@ -172,12 +172,12 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
 
     /**
-     *  ƥץ졼ѿ˻ȤƤ
+     *  テンプレート変数に参照を割り当てる
      * 
      *  @access public
      *  @todo fixme
-     *  @param string $name ѿ̾
-     *  @param mixed $value 
+     *  @param string $name 変数名
+     *  @param mixed $value 値
      */
     function setPropByRef($name, &$value)
     {
@@ -192,7 +192,7 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
      */
     function setPlugin($name, $type, $plugin)
     {
-        //Smartyץ饰ؿ̵ͭå
+        //Smartyプラグイン関数の有無をチェック
         if (is_callable($plugin) === false) {
             return Ethna::raiseWarning('Does not exists.');
         }
@@ -214,7 +214,7 @@ class Ethna_Renderer_Rhaco extends Ethna_Renderer
     }
 
     /**
-     *  ǥեȤ.
+     *  デフォルトの設定.
      *
      *  @access public
      */
@@ -304,8 +304,8 @@ class TemplateParser_Ethna extends TemplateParser
      * @access protected
      * @param string $src
      */
-    function _exec9002_smartyfunctions($src)
-    {
+    function _exec9002_smartyfunctions($src){
+
         $tag = new SimpleTag();
         $smarty_plugin_list = $this->getSmartyPluginList();
 
@@ -351,16 +351,6 @@ class TemplateParser_Ethna extends TemplateParser
         return $src;
     }
 
-    /**
-     * TemplateParser _getTagName
-     *
-     * @access protected
-     * @param string $value
-     */
-    function _getTagName($value)
-    {
-        return sprintf("rt:%s",$value);
-    }
 }
 
 ?>
