@@ -31,10 +31,10 @@ class Ethna_Plugin_Validator_Mbstrmin_Test extends Ethna_UnitTestBase
         $this->vld->af->setDef('namae_mbstr', $form_mbstr);
 
         $pear_error = $this->vld->validate('namae_mbstr', 'あいう', $form_mbstr);
-        $this->assertFalse(is_a($pear_error, 'PEAR_Error'));
+        $this->assertFalse(is_a($pear_error, 'Ethna_Error'));
 
         $pear_error = $this->vld->validate('namae_mbstr', 'あい', $form_mbstr);
-        $this->assertTrue(is_a($pear_error, 'PEAR_Error'));
+        $this->assertTrue(is_a($pear_error, 'Ethna_Error'));
         $this->assertEqual(E_FORM_MIN_STRING,$pear_error->getCode());
 
         //  TODO: Error Message Test.
